summaryrefslogtreecommitdiff
path: root/libgpsd_core.c
diff options
context:
space:
mode:
Diffstat (limited to 'libgpsd_core.c')
-rw-r--r--libgpsd_core.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libgpsd_core.c b/libgpsd_core.c
index a752f10f..15fa8070 100644
--- a/libgpsd_core.c
+++ b/libgpsd_core.c
@@ -1054,7 +1054,7 @@ int gpsd_await_data(fd_set *rfds,
* actually matter here since select returns whenever one of
* the file descriptors in the set goes ready. The point
* of tracking maxfd is to keep the set of descriptors that
* select(2) has to poll here as small as possible (for
* low-clock-rate SBCs and the like).
*
* pselect() is preferable to vanilla select, to eliminate
@@ -1098,7 +1098,7 @@ int gpsd_await_data(fd_set *rfds,
if (FD_ISSET(i, rfds))
str_appendf(dbuf, sizeof(dbuf), " %d ", i);
gpsd_log(errout, LOG_SPIN,
- "select() {%s} at %f (errno %d)\n",
+ "pselect() {%s} at %f (errno %d)\n",
dbuf, timestamp(), errno);
}
@@ -1054,7 +1054,7 @@ int gpsd_await_data(fd_set *rfds,
* the file descriptors in the set goes ready. The point
* of tracking maxfd is to keep the set of descriptors that
- * select(2) has to poll here as small as possible (for
+ * pselect(2) has to poll here as small as possible (for
* low-clock-rate SBCs and the like).
*